@@ -4,7 +4,7 @@
 
 Utilities classes and standalone functions to use for FA API interaction and communication
 """
-
+import re
 from datetime import datetime
 from html import unescape
 from json import dumps
@@ -24,12 +24,30 @@ def make_search_string(strin: str, repattern: Pattern[AnyStr]) -> str:
         and digits
     -   lowercases strings
     -   sorts in the default order
-    -   merges strings delimited by spaces
+    -   merges a sorted list into a string with spaces
 
     :param strin: given raw string
     :param repattern: re module regular expression compiled pattern for splitting string
     :return: unified search string
     """
+    return chr(0x0020).join(make_search_list(strin, repattern))
+
+
+def make_search_list(strin: str, repattern: Pattern[AnyStr]) -> List[str]:
+    """
+    This does the following:
+
+    -   splits string by given compiled regular expression pattern, consequitive delimeters treated as one,
+        ignores empty strings, any pattern works, supposed that "[ .,:;-]+" is used
+    -   removes from strings all symbols except latin letters, including UTF-0080+, cyrillic letters
+        and digits
+    -   lowercases strings
+    -   sorts in the default order
+
+    :param strin: given raw string
+    :param repattern: re module regular expression compiled pattern for splitting string
+    :return: unified search string in a form of sorted list
+    """
     _ALLOWED = ("0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz"
                 "¡¿ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏÐÑÒÓÔÕÖØÙÚÛÜÝÞßàáâãäåæçèéêëìíîïðñòóôõöøùúûüýþÿЀЁЂЃЄЅІЇЈЉЊЋЌЍЎЏ"
                 "АБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмнопрстуфхцчшщъыьэюя"
@@ -46,7 +64,7 @@ def make_search_string(strin: str, repattern: Pattern[AnyStr]) -> str:
             if _item_processed:
                 _split_processed.append(_item_processed.lower())
     _split_processed.sort()
-    return chr(0x0020).join(_split_processed)
+    return _split_processed
 
 
 # noinspection DuplicatedCode
@@ -105,7 +123,9 @@ def gettag(htmltag: str) -> str:
         if not _end < 0:
             _c = htmltag[(_beg + 1):_end]
     if _c != htmltag:
-        return chr(0x0020).join(strnorm(unescape(_c)))
+        # Compile regular expression pattern for make_search_string()
+        _re_pattern: Pattern[AnyStr] = re.compile("[ .,:;-]+")
+        return chr(0x0020).join(make_search_string(unescape(_c), _re_pattern))
     return unescape(htmltag)
 
 
@@ -124,6 +144,8 @@ async def fagetrefs(fadomain: str,
     _SSL = None
     # Debug log for output
     _debug_log = str()
+    # Compile regular expression pattern for make_search_string()
+    _re_pattern: Pattern[AnyStr] = re.compile("[ .,:;-]+")
     # Get all users
     r = await httpsession.post(f"https://{fadomain}.facilityapps.com/api/1.0/users_manager/data",
                                headers={"Accept": "application/json",
@@ -138,7 +160,7 @@ async def fagetrefs(fadomain: str,
     _user_ref = dict()
     for _i in _users_json["data"]:
         # Normalise the user name with strnorm() and join resulting list with spaces
-        _user_ref[chr(0x0020).join(strnorm(unescape(_i["contact.name"])))] = _i["id"]
+        _user_ref[chr(0x0020).join(make_search_string(unescape(_i["contact.name"]), _re_pattern))] = _i["id"]
     _debug_log += f"User reference built:\n{dumps(_user_ref, indent=3, ensure_ascii=False)}" + "\n"
     # Get all sites
     r = await httpsession.post(f"https://{fadomain}.facilityapps.com/api/1.0/site_manager/site_data",
@@ -154,7 +176,7 @@ async def fagetrefs(fadomain: str,
     _site_ref = dict()
     for _i in _sites_json["data"]:
         # Normalise the site name with strnorm() and join resulting list with spaces
-        _site_ref[chr(0x0020).join(strnorm(unescape(_i["name"])))] = _i["id"]
+        _site_ref[chr(0x0020).join(make_search_string(unescape(_i["name"]), _re_pattern))] = _i["id"]
     _debug_log += f"Sites reference built:\n{dumps(_site_ref, indent=3, ensure_ascii=False)}" + "\n"
     # Get all floors and spaces
     r = await httpsession.post(f"https://{fadomain}.facilityapps.com/api/1.0/floorplan/spaces/list",
