@@ -6,6 +6,7 @@ Class representing single FA task used for planning tasks through FA API
 """
 
 from datetime import datetime, timedelta
+from hashlib import sha512
 from json import dumps
 from typing import Dict, List, Optional, Union
 
@@ -27,7 +28,8 @@ class FATask:
                  approvers: Optional[List[int]] = None,
                  watchers: Optional[List[int]] = None,
                  spaces: Optional[Dict[str, List[int]]] = None,
-                 duration: Optional[timedelta] = None) -> None:
+                 duration: Optional[timedelta] = None,
+                 identity: Optional[str] = None) -> None:
         """
         Constructs the FA task object.
 
@@ -42,7 +44,9 @@ class FATask:
         :param watchers: list of user IDs in FA who will have access to watch task status
         :param spaces: dict of spaces on which to plan the task, {"floor ID": [list of space IDs]}
         :param duration: duration of task as timedelta object
+        :param identity: task identity string indicating from which MS Excel, worksheet and line this task was created
         """
+        self._version = 1
         _d = (0, 0, 0)
         if duration is not None:
             (_dh, _ds) = divmod(duration.total_seconds(), 3600)
@@ -91,6 +95,7 @@ class FATask:
                         },
                 "floors_spaces":                      dict() if spaces is None else spaces
                 }
+        self._identity = str(identity)
 
     def __getitem__(self, item: str):
         """ Returns the task property by name """
@@ -105,6 +110,26 @@ class FATask:
         """
         return dumps({"_token": token, **self._task}, ensure_ascii=False)
 
+    def getsha512(self) -> bytes:
+        """
+        Get SHA512 hash of FA task as bytes
+        """
+        return sha512(dumps({"_version": self._version, **self._task}, ensure_ascii=False).encode("utf-8")).digest()
+
+    def getversion(self) -> int:
+        """
+        Get version of FATask object structure
+        """
+        return self._version
+
+    def getidentity(self) -> str:
+        """
+        Get the FA task identity string
+
+        :return: string with task identity as specified at task creation
+        """
+        return self._identity
+
     def setrecurrence(self,
                       repeat: str,
                       *,
